Struct style::sharing::ValidationData
[−]
[src]
pub struct ValidationData { /* fields omitted */ }Some data we want to avoid recomputing all the time while trying to share style.
Methods
impl ValidationData[src]
pub fn take(&mut self) -> Self[src]
Move the cached data to a new instance, and return it.
pub fn pres_hints<E>(&mut self, element: E) -> &[ApplicableDeclarationBlock] where
E: TElement, [src]
E: TElement,
Get or compute the list of presentational attributes associated with this element.
pub fn class_list<E>(&mut self, element: E) -> &[Atom] where
E: TElement, [src]
E: TElement,
Get or compute the class-list associated with this element.
pub fn parent_style_identity<E>(&mut self, el: E) -> OpaqueComputedValues where
E: TElement, [src]
E: TElement,
Get or compute the parent style identity.